# -*- coding: utf-8 -*-
from setuphelpers import *

bin_contains = "FBReader"
appx_package = "FBReader.ORGLimited.FBReader"
appx_dir = makepath(programfiles, "WindowsAppsInstallers")
file_extension = "msix"


def install():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_name = glob.glob("*%s*.%s" % (bin_contains, file_extension))[0]
    bin_path = makepath(appx_dir, bin_name)

    # Checking minimum Windows version
    if windows_version() >= WindowsVersions.Windows10v1809:
        # Copying the software
        if not isdir(appx_dir):
            mkdirs(appx_dir)
        else:
            for appx_file in glob.glob("%s/*%s*.%s" % (appx_dir, bin_contains, file_extension)):
                if not package_version in appx_file:
                    remove_file(appx_file)
        if not isfile(bin_path):
            print("Copying: %s to: %s" % (bin_name, appx_dir))
            filecopyto(bin_name, appx_dir)
    else:
        error(
            "This Windows version (%s) need to be upgraded to minimum version (%s) to use this package"
            % (windows_version(), WindowsVersions.Windows10v1809)
        )


def uninstall():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_path = glob.glob(makepath(appx_dir, "*%s*.%s" % (bin_contains, file_extension)))[0]

    # Uninstalling the package
    remove_appx(appx_package)
    if isfile(bin_path):
        remove_file(bin_path)
    if isdir(appx_dir) and dir_is_empty(appx_dir):
        print("Removing: %s since he is empty" % (appx_dir))
        remove_tree(appx_dir)


def session_setup():
    # Declaring local variables
    package_version = control.get_software_version()
    app_name = control.name
    bin_path = glob.glob(makepath(appx_dir, "*%s*.%s" % (bin_contains, file_extension)))[0]
    bin_name = bin_path.split("\\")[-1]

    # Installing the software in user env
    appx_version = get_powershell_str("Get-AppxPackage -Name %s" % appx_package, "Version")
    if not appx_version or appx_version < package_version or force:
        print("Installing: %s" % bin_name)
        run_powershell('Add-AppxPackage -Path "%s"' % bin_path)
    else:
        print("%s is installed in correct version (%s)" % (app_name, appx_version))

def remove_appx(package, default_user=True):
    """Remove Windows AppX package from the computer environment, excluding NonRemovable packages.

    Args:
        package (str): AppX package name. You can use an asterisk (*) as a wildcard.
        default_user (bool): Remove AppX package from the Windows image to prevent installation for new users.

    .. versionchanged:: 2.5
        No longer try to remove NonRemovable AppX package

    .. versionchanger:: 2.6
        No longer use run_powershell for uninstall
    """

    if running_as_admin() or running_as_system():
        if default_user:
            ps_script = f'Get-AppXProvisionedPackage -Online | Where-Object DisplayName -Like ""{package}"" | Remove-AppxProvisionedPackage -Online -AllUsers'
            run_powershell_script(ps_script, output_format="text")

        ps_script = f'Get-AppxPackage -Name ""{package}"" -AllUsers | Where-Object -property NonRemovable -notlike True | Remove-AppxPackage -AllUsers'
        run_powershell_script(ps_script, output_format="text")

    else:
        ps_script = f'Get-AppxPackage -Name ""{package}"" | Where-Object -property NonRemovable -notlike True | Remove-AppxPackage'
        run_powershell_script(ps_script, output_format="text")